VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "POP3_Test"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' $Id: POP3_Test.cls,v 1.9 2009-09-29 09:37:45 dcharlton Exp $
' Class to demonstrate an secure connection to an POP3 server
'
Option Explicit

Private pop3 As New CSMAILLib.POP3Client
Private m_errorNo As Long
Private m_errorStr As String

Implements TestTypeBase
Private m_TestInfo As TestInfoCtl
Private WithEvents m_Log As CSMAILLib.LogHandler
Attribute m_Log.VB_VarHelpID = -1

'-----------------------------------------------------------------------------
' Construction
'-----------------------------------------------------------------------------

Private Sub Class_initialize()
' setup the new log handler
Set m_Log = New CSMAILLib.LogHandler
m_Log.FacilityFlags = CSMAILLib.LOG_F_SSL Or CSMAILLib.LOG_F_PROTOCOL
m_Log.Level = CSMAILLib.LOG_S_INFORMATION

End Sub

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.Connect() method
'
'-----------------------------------------------------------------------------

Private Function TestTypeBase_Connect() As Boolean
Dim ssl As CSMAILLib.SSLInfo
Dim sInfo As String
TestTypeBase_Connect = False

On Error GoTo HandleError

If m_TestInfo.UseSSL Then
    
    ' using SSL ...


    ' Instantiate an SSLInfo object for the connection
    Set ssl = New CSMAILLib.SSLInfo

    ' Set SSL options from the options specified in the GUI
    ' In a real application you are unlikely to set many, if any,
    ' of these options; the defaults are generally the best!
    
    ssl.Mode = m_TestInfo.Mode
    
    ssl.Option(CSMAILLib.SSLConnectionProtocolIn) = m_TestInfo.Protocols
    ssl.Option(CSMAILLib.SSLConnectionCipherIn) = m_TestInfo.Ciphers
    ssl.Option(CSMAILLib.SSLMinCipherStrength) = m_TestInfo.MinCipherStrength
    ssl.Option(CSMAILLib.SSLMaxCipherStrength) = m_TestInfo.MaxCipherStrength
    
    ssl.Option(CSMAILLib.SSLNoServerNameCheck) = m_TestInfo.SSLFlag(SSLNoServerNameCheck)
    ssl.Option(SSLNoServerCertificateValidation) = m_TestInfo.SSLFlag(SSLNoServerCertificateValidation)
    ssl.Option(SSLRevocationCheckAll) = m_TestInfo.SSLFlag(SSLRevocationCheckAll)
    ssl.Option(SSLRevocationCheckEnd) = m_TestInfo.SSLFlag(SSLRevocationCheckEnd)
    ssl.Option(SSLRevocationExcludeRoot) = m_TestInfo.SSLFlag(SSLRevocationExcludeRoot)
    ssl.Option(SSLRevocationIgnoreNRC) = m_TestInfo.SSLFlag(SSLRevocationIgnoreNRC)
    ssl.Option(SSLRevocationIgnoreRO) = m_TestInfo.SSLFlag(SSLRevocationIgnoreRO)
	ssl.Option(SSLNoDefaultCredentials) = m_TestInfo.SSLFlag(SSLNoDefaultCredentials)
	ssl.Option(SSLNoDefaultCredentialsHard) = m_TestInfo.SSLFlag(SSLNoDefaultCredentialsHard)
    
    ' Add the SSLInfo object to the POP3Client. Calls to POP3Client.Connect()
    ' will now attempt to estabish a secure connection to the server
    
    pop3.SetAdvancedHandler ssl
Else
    ' not using SSL ...

    pop3.SetAdvancedHandler New CSMAILLib.NULLSSLInfo
    End If


    
' Add the LogHandler object to the SMTPClient. Log events will be notified
' on the OnLogMessage() event of the LogHandler object.

If m_TestInfo.LogFacility <> 0 Then
    m_Log.FacilityFlags = m_TestInfo.LogFacility
    pop3.SetAdvancedHandler m_Log
Else
    Dim nullLog As New CSMAILLib.NULLLogHandler
    pop3.SetAdvancedHandler nullLog
    End If


' Open and Close a connection the server
' To keep things simple we don't retrieve any messages here; once an secure
' connection is established the POP3Client object behaves just like the
' non-SSL version, so you'd just call RetrieveMessages etc as usual in your
' application


pop3.Connect m_TestInfo.ServerName, m_TestInfo.UserName, m_TestInfo.Password, m_TestInfo.Port
pop3.Close

' Get the attributes of the SSL connection. Again, in a real application
' you're unlikely to need any of these.

sInfo = "OK:"

If m_TestInfo.UseSSL Then
    sInfo = sInfo & "; " & LookupTextById(Protocol, ssl.Option(CSMAILLib.SSLConnectionProtocolOut))
    sInfo = sInfo & "; " & LookupTextById(Cipher, ssl.Option(CSMAILLib.SSLConnectionCipherOut))
    sInfo = sInfo & " " & ssl.Option(CSMAILLib.SSLCipherStrength) & " bits "
    sInfo = sInfo & "; " & LookupTextById(Hash, ssl.Option(CSMAILLib.SSLHash))
    sInfo = sInfo & " " & ssl.Option(CSMAILLib.SSLHashStrength) & " bits "
    sInfo = sInfo & "; " & LookupTextById(Exchange, ssl.Option(CSMAILLib.SSLExchange))
    sInfo = sInfo & " " & ssl.Option(CSMAILLib.SSLExchangeStrength) & " bits "
End If

m_errorStr = sInfo
m_errorNo = 0

m_Log.Log CSMAILLib.LOG_S_INFORMATION, CSMAILLib.LOG_F_USER, sInfo

TestTypeBase_Connect = True


Exit Function

HandleError:
    m_errorNo = Err.Number
    m_errorStr = "FAIL:" & Err.Description
    m_Log.Log CSMAILLib.LOG_S_INFORMATION, CSMAILLib.LOG_F_USER, m_errorStr


End Function

'-----------------------------------------------------------------------------
' Event handler for LogHandler object
'-----------------------------------------------------------------------------

Private Sub m_Log_OnLogMessage(ByVal Severity As Long, ByVal Facility As Long, ByVal Message As String)

' just pass onto the gui object
m_TestInfo.Log Severity, Facility, Message

End Sub

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.Name property
'-----------------------------------------------------------------------------

Private Property Get TestTypeBase_Name() As String
TestTypeBase_Name = "POP3"
End Property

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.TestParams property
'-----------------------------------------------------------------------------

Public Property Set TestTypeBase_TestParams(p As TestInfoCtl)
Set m_TestInfo = p
End Property

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.DefaultSecurePort property
'-----------------------------------------------------------------------------

Public Property Get TestTypeBase_DefaultSecurePort() As Long
TestTypeBase_DefaultSecurePort = 995
End Property

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.DefaultStandardPort property
'-----------------------------------------------------------------------------

Public Property Get TestTypeBase_DefaultStandardPort() As Long
TestTypeBase_DefaultStandardPort = 110
End Property


'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.ErrorNumber property
'-----------------------------------------------------------------------------


Public Property Get TestTypeBase_ErrorNumber() As Long
TestTypeBase_ErrorNumber = m_errorNo
End Property

'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.ErrorString property
'-----------------------------------------------------------------------------

Public Property Get TestTypeBase_ErrorString() As String
TestTypeBase_ErrorString = m_errorStr
End Property


'-----------------------------------------------------------------------------
' Implementation of TestTypeBase.ExtendedError property
'-----------------------------------------------------------------------------

Public Property Get TestTypeBase_ExtendedError() As CSMAILLib.ErrorInfo
Set TestTypeBase_ExtendedError = pop3.ExtendedError
End Property





